@@ -118,14 +118,16 @@ class VscsiVolumeAdapter(v_driver.FibreChannelVolumeAdapter):
                 vios_w, volume_id)
             # If we found one, no need to check the others.
             found = found or hdisk.good_discovery(status, device_name)
+            # if valid udid is returned save in mig_data
+            volume_key = 'vscsi-' + volume_id
+            if udid is not None:
+                mig_data[volume_key] = udid
 
-        if not found:
+        if not found or volume_key not in mig_data:
             ex_args = dict(volume_id=volume_id,
                            instance_name=self.instance.name)
             raise p_exc.VolumePreMigrationFailed(**ex_args)
 
-        mig_data['vscsi-' + volume_id] = udid
-
     def _cleanup_volume(self, udid):
         """Cleanup the hdisk associated with this udid."""
 
@@ -249,6 +251,12 @@ class VscsiVolumeAdapter(v_driver.FibreChannelVolumeAdapter):
             # Get the slot and LUA to assign.
             slot, lua = slot_mgr.build_map.get_vscsi_slot(vios_w, udid)
 
+            if slot_mgr.is_rebuild and not slot:
+                LOG.debug('Detected a device with UDID %s on VIOS %s on the '
+                          'rebuild that did not exist on the source.  '
+                          'Ignoring.', udid, vios_w.uuid)
+                return False
+
             if hdisk.good_discovery(status, device_name):
                 # Found a hdisk on this Virtual I/O Server.  Add the action to
                 # map it to the VM when the stg_ftsk is executed.
@@ -359,7 +367,12 @@ class VscsiVolumeAdapter(v_driver.FibreChannelVolumeAdapter):
             udid, device_name = None, None
             try:
                 udid = self._get_udid()
-                if not udid:
+
+                if udid:
+                    # This will only work if vios_w has the Storage XAG.
+                    device_name = vios_w.hdisk_from_uuid(udid)
+
+                if not udid or not device_name:
                     # We lost our bdm data. We'll need to discover it.
                     status, device_name, udid = self._discover_volume_on_vios(
                         vios_w, self.volume_id)
@@ -377,18 +390,6 @@ class VscsiVolumeAdapter(v_driver.FibreChannelVolumeAdapter):
                             {'volume_id': self.volume_id, 'vios': vios_w.name})
                         return False
 
-                if udid and not device_name:
-                    device_name = vios_w.hdisk_from_uuid(udid)
-
-                if not device_name:
-                    LOG.warning(_LW(
-                        "Disconnect Volume: No mapped device found on Virtual "
-                        "I/O Server %(vios)s for volume %(volume_id)s.  "
-                        "Volume UDID: %(volume_uid)s"),
-                        {'volume_uid': udid, 'volume_id': self.volume_id,
-                         'vios': vios_w.name})
-                    return False
-
             except Exception as e:
                 LOG.warning(_LW(
                     "Disconnect Volume: Failed to find disk on Virtual I/O "
